        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,12,13,15,21,25,26,27,30,32,36,41,44,45,48,49';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 11 <br>5,6,11,19,22,28,29,38,39,40,47';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>9,14,16,18,23,24,31,35,37,42,43';}
       if(rr==6 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 6 <br>17,20,33,34,46,50';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,12,13,15,21,25,26,27,30,32,36,41,44,45,48,49';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 11 <br>5,6,11,19,22,28,29,38,39,40,47';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>9,14,16,18,23,24,31,35,37,42,43';}
       if(rr==29 && cc==4){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 6 <br>17,20,33,34,46,50';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,12,13,15,21,25,26,27,30,32,36,41,44,45,48,49';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 11 <br>5,6,11,19,22,28,29,38,39,40,47';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>9,14,16,18,23,24,31,35,37,42,43';}
       if(rr==30 && cc==4){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 6 <br>17,20,33,34,46,50';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,12,13,15,21,25,26,27,30,32,36,41,44,45,48,49';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 11 <br>5,6,11,19,22,28,29,38,39,40,47';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>9,14,16,18,23,24,31,35,37,42,43';}
       if(rr==31 && cc==4){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 6 <br>17,20,33,34,46,50';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,12,13,15,21,25,26,27,30,32,36,41,44,45,48,49';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 11 <br>5,6,11,19,22,28,29,38,39,40,47';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>9,14,16,18,23,24,31,35,37,42,43';}
       if(rr==32 && cc==4){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 6 <br>17,20,33,34,46,50';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>12</strong> miembros: 23 <strong>control</strong><br>0,1,2,3,4,7,8,10,12,13,15,21,25,26,27,30,32,36,41,44,45,48,49';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 11 <br>5,6,11,19,22,28,29,38,39,40,47';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>14</strong> miembros: 11 <br>9,14,16,18,23,24,31,35,37,42,43';}
       if(rr==33 && cc==4){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>4</strong> representante: <strong>50</strong> miembros: 6 <br>17,20,33,34,46,50';}
}
